Tag getpermissions

## getpermissions query user permissions

name
  getpermissions
xml namespace
  http://moyaproject.com/auth
defined
  /home/will/projects/moya/moya/applications/auth/logic/tags.xml (line 5)

Get list of permissions for a given user

            <signature>            <attribute name="user" type="expression">                A User object            </attribute>        </signature>

attributes
name | purpose | type | required?
--- | --- | --- | ---
dst | Destination | Reference | No
lazy | Enable lazy evaluation | boolean | No
user | A User object | expression | No

inherited attributes
name | purpose | type | required?
--- | --- | --- | ---
if | Conditional expression | expression | No